/*

Demonstrates the use of the Parallax WS2812B RGB Led Module (#28085)
and similar LED boards.

This demo cycles one LED through the three primary colors, red, blue, and
green, slowly fading in for each color.

REQUIRES the Adafruot NeoPixel library available here:
https://github.com/adafruit/Adafruit_NeoPixel

*/

#include <Adafruit_NeoPixel.h>         // Include Adafruit NeoPixel library
#define PIN            6               // LED on digital pin 6
#define NUMLEDS        1               // Use total of 1 LED

// Create 'leds' object to drive LEDs
Adafruit_NeoPixel leds = Adafruit_NeoPixel(NUMLEDS, PIN, NEO_GRB + NEO_KHZ800);

int wait = 5;                         // Standard wait delay of 5 milliseconds 

void setup() {
  leds.begin();                       // Initialize 'leds' object

  //Make sure LED is off to demonstrate start of sketch
  leds.setPixelColor(0, leds.Color(0, 0, 0));  // Turn off LED
  leds.show();                        // Set new value
  delay(500);
  
}

// Loop through changing R, G, and B colors
// Each color fades in from off (i=0) to fully on (i=255)
void loop() {
  for(int i=0; i<255; i++) {            // Count up color units from 0 to 255
    leds.setPixelColor(0, leds.Color(i, 0, 0));  // Color mix for LED
    leds.show();                        // Set the LED
    delay(wait);                        // Delay for visual effect
  }
  for(int i=0; i<255; i++) {            // Loop through next color change
    leds.setPixelColor(0, leds.Color(0, i, 0)); 
    leds.show(); 
    delay(wait); 
  }
  for(int i=0; i<255; i++) {            // Loop through next color change
    leds.setPixelColor(0, leds.Color(0, 0, i));
    leds.show(); 
    delay(wait);
  }
}
